@@ -111,16 +111,16 @@ class DBConnect:
 
     def delete_docu(self, find_docu: dict, many: bool = False, false_delete: bool = False) -> dict:
         try:
-            find_docu = handle_db_id(find_docu)
             if false_delete:
                 # 假删除流程
-                modify_dict = {'$set': {'remove_time': datetime.today()}}
+                modify_dict = {'remove_time': datetime.today()}
                 result = self.update_docu(
                     find_docu=find_docu, modify_docu=modify_dict, many=many)
                 if not result['modified_count']:
                     logging.error('MongoDB(组件)出现删除异常: 没有任何文档被假删除')
                 return {'deleted_count': result['modified_count'], 'false_delete': false_delete}
             else:
+                find_docu = handle_db_id(find_docu)
                 find_docu = handle_db_remove(find_docu)
                 # 真删除流程
                 if many:
