@@ -89,7 +89,8 @@ def handle_db_id(data_dict: dict) -> dict:
                 data_dict['_id'] = data_dict['id']
             del data_dict['id']
         # 处理批量操作时，字符串类型ID问题
-        if data_dict.__contains__('_id') and isinstance(data_dict['_id'], dict):  # 判断存在_id，并且值为字典则做特殊处理
+        # 判断存在_id，并且值为字典则做特殊处理
+        if data_dict.__contains__('_id') and isinstance(data_dict['_id'], dict):
             for key, value in data_dict['_id'].items():
                 if isinstance(value, list):  # 查找ID是列表
                     for i in range(len(value)):
@@ -133,3 +134,16 @@ def handle_abnormal(message: str, status: int, header: dict = {'Content-Type': '
         return return_body, status, header
     else:
         abort(Response(json.dumps(return_body), status, header))
+
+
+def handle_time_difference(start_timestamp: int, end_timestamp: int) -> float:
+    if len(str(start_timestamp)) == 13:
+        start_date = datetime.fromtimestamp(start_timestamp/1000)
+        end_date = datetime.fromtimestamp(end_timestamp/1000)
+    elif len(str(start_timestamp)) == 10:
+        start_date = datetime.fromtimestamp(start_timestamp)
+        end_date = datetime.fromtimestamp(end_timestamp)
+    else:
+        handle_abnormal(message='时间戳格式不规范', status=400,)
+    difference = (end_date - start_date).total_seconds()
+    return difference
